@@ -1,4 +1,6 @@
 #' Joint analysis of variance
+#' @description
+#' `r badge('stable')`
 #'
 #' Performs a joint analysis of variance to check for the presence of
 #' genotype-vs-environment interactions using both randomized complete block and
@@ -13,34 +15,34 @@
 #' @param rep The name of the column that contains the levels of the
 #'   replications/blocks.
 #' @param resp The response variable(s). To analyze multiple variables in a
-#'   single procedure a vector of variables may be used. For example \code{resp
-#'   = c(var1, var2, var3)}.
-#' @param block Defaults to \code{NULL}. In this case, a randomized complete
+#'   single procedure a vector of variables may be used. For example `resp
+#'   = c(var1, var2, var3)`.
+#' @param block Defaults to `NULL`. In this case, a randomized complete
 #'   block design is considered. If block is informed, then a resolvable
 #'   alpha-lattice design (Patterson and Williams, 1976) is employed.
-#'   \strong{All effects, except the error, are assumed to be fixed.}
-#' @param verbose Logical argument. If \code{verbose = FALSE} the code will run
+#'   **All effects, except the error, are assumed to be fixed.**
+#' @param verbose Logical argument. If `verbose = FALSE` the code will run
 #'   silently.
 #' @references Patterson, H.D., and E.R. Williams. 1976. A new class of
 #' resolvable incomplete block designs. Biometrika 63:83-92.
 #' @return A list where each element is the result for one variable containing
 #'   the following objects:
 #'
-#'  * \strong{anova:} The two-way ANOVA table
-#'  * \strong{model:} The model of class \code{lm}.
-#'  * \strong{augment:} Information about each observation in the dataset. This
-#'  includes predicted values in the \code{fitted} column, residuals in the
-#'  \code{resid} column, standardized residuals in the \code{stdres} column,
-#'  the diagonal of the 'hat' matrix in the \code{hat}, and standard errors for
-#'  the fitted values in the \code{se.fit} column.
-#'  * \strong{details:} A tibble with the following data: \code{Ngen}, the
-#'  number of genotypes; \code{OVmean}, the grand mean; \code{Min}, the minimum
-#'  observed (returning the genotype and replication/block); \code{Max} the
-#'  maximum observed, \code{MinGEN} the loser winner genotype, \code{MaxGEN},
+#'  * **anova:** The two-way ANOVA table
+#'  * **model:** The model of class `lm`.
+#'  * **augment:** Information about each observation in the dataset. This
+#'  includes predicted values in the `fitted` column, residuals in the
+#'  `resid` column, standardized residuals in the `stdres` column,
+#'  the diagonal of the 'hat' matrix in the `hat`, and standard errors for
+#'  the fitted values in the `se.fit` column.
+#'  * **details:** A tibble with the following data: `Ngen`, the
+#'  number of genotypes; `OVmean`, the grand mean; `Min`, the minimum
+#'  observed (returning the genotype and replication/block); `Max` the
+#'  maximum observed, `MinGEN` the loser winner genotype, `MaxGEN`,
 #'  the winner genotype.
 #'
 #' @md
-#' @seealso \code{\link{get_model_data}} \code{\link{anova_ind}}
+#' @seealso [get_model_data()] [anova_ind()]
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @export
 #' @examples
@@ -115,7 +117,7 @@ anova_joint <- function(.data,
       CV <- tibble(Source = "CV(%)", Df = as.numeric(sqrt(anova[5, 4]) / mean(data$mean) * 100))
       msr <- tibble(Source = "MSR+/MSR-", Df = max(msr) / min(msr))
       ovmean <- tibble(Source = "OVmean", Df = mean(data$mean))
-      temp <- rbind_fill(anova, CV, msr, ovmean, fill = NA)
+      temp <- rbind_fill_id(anova, CV, msr, ovmean)
     } else{
       msr <- do.call(rbind,
                      lapply(msr, function(x){
@@ -131,7 +133,7 @@ anova_joint <- function(.data,
       CV <- tibble(Source = "CV(%)", Df = as.numeric(sqrt(anova[6, 4]) / mean(data$mean) * 100))
       msr <- tibble(Source = "MSR+/MSR-", Df = max(msr) / min(msr))
       ovmean <- tibble(Source = "OVmean", Df = mean(data$mean))
-      temp <- rbind_fill(anova, CV, msr, ovmean, fill = NA)
+      temp <- rbind_fill_id(anova, CV, msr, ovmean)
     }
     influence <- lm.influence(model)
     augment <- model$model %>%
@@ -183,16 +185,16 @@ anova_joint <- function(.data,
 
 #' Several types of residual plots
 #'
-#' Residual plots for a output model of class \code{anova_joint}. Seven types
+#' Residual plots for a output model of class `anova_joint`. Seven types
 #' of plots are produced: (1) Residuals vs fitted, (2) normal Q-Q plot for the
 #' residuals, (3) scale-location plot (standardized residuals vs Fitted Values),
 #' (4) standardized residuals vs Factor-levels, (5) Histogram of raw residuals
 #' and (6) standardized residuals vs observation order, and (7) 1:1 line plot.
 #'
 #'
-#' @param x An object of class \code{anova_joint}.
+#' @param x An object of class `anova_joint`.
 #' @param ... Additional arguments passed on to the function
-#'   \code{\link{residual_plots}}
+#'   [residual_plots()]
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @method plot anova_joint
 #' @export
@@ -219,17 +221,17 @@ plot.anova_joint <- function(x, ...) {
 
 #' Print an object of class anova_joint
 #'
-#' Print the \code{anova_joint} object in two ways. By default, the results are shown
+#' Print the `anova_joint` object in two ways. By default, the results are shown
 #' in the R console. The results can also be exported to the directory into a
 #' *.txt file.
 #'
-#' @param x An object of class \code{anova_joint}.
-#' @param export A logical argument. If \code{TRUE}, a *.txt file is exported to
+#' @param x An object of class `anova_joint`.
+#' @param export A logical argument. If `TRUE`, a *.txt file is exported to
 #'   the working directory.
-#' @param file.name The name of the file if \code{export = TRUE}
+#' @param file.name The name of the file if `export = TRUE`
 #' @param digits The significant digits to be shown.
 #' @param ... Options used by the tibble package to format the output. See
-#'   \code{\link[tibble:formatting]{tibble::print()}} for more details.
+#'   [`tibble::print()`][tibble::formatting] for more details.
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @method print anova_joint
 #' @export
