@@ -1,4 +1,6 @@
 #' Stability analysis based on Wricke's model
+#' @description
+#' `r badge('stable')`
 #'
 #' The function computes the ecovalence (Wricke, 1965) for stability analysis.
 #'
@@ -11,11 +13,11 @@
 #' @param rep The name of the column that contains the levels of the
 #'   replications/blocks.
 #' @param resp The response variable(s). To analyze multiple variables in a
-#'   single procedure use, for example, \code{resp = c(var1, var2, var3)}.
-#' @param verbose Logical argument. If \code{verbose = FALSE} the code will run
+#'   single procedure use, for example, `resp = c(var1, var2, var3)`.
+#' @param verbose Logical argument. If `verbose = FALSE` the code will run
 #'   silently.
-#' @return An object of class \code{ecovalence} containing the results for each
-#'   variable used in the argument \code{resp}.
+#' @return An object of class `ecovalence` containing the results for each
+#'   variable used in the argument `resp`.
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @references Wricke, G. 1965. Zur berechnung der okovalenz bei sommerweizen
 #'   und hafer. Z. Pflanzenzuchtg 52:127-138.
@@ -43,9 +45,7 @@ ecovalence <- function(.data, env, gen, rep, resp, verbose = TRUE) {
   listres <- list()
   nvar <- ncol(vars)
   if (verbose == TRUE) {
-    pb <- progress_bar$new(
-      format = "Evaluating the variable :what [:bar]:percent",
-      clear = FALSE, total = nvar, width = 90)
+    pb <- progress(max = nvar, style = 4)
   }
   for (var in 1:nvar) {
     data <- factors %>%
@@ -60,14 +60,16 @@ ecovalence <- function(.data, env, gen, rep, resp, verbose = TRUE) {
     data3 <- mutate(data2,
                     ge = residuals(lm(Y ~ ENV + GEN, data = data2)))
     ge_effect <- make_mat(data3, GEN, ENV, ge)
-    Ecoval <- rowSums(ge_effect^2 * nlevels(data$REP))
+    Ecoval <- rowSums(ge_effect^2 * nlevels(data$REP), na.rm = TRUE)
     Ecov_perc <- (Ecoval/sum(Ecoval)) * 100
     rank <- rank(Ecoval)
     temp <- cbind(ge_effect, Ecoval, Ecov_perc, rank) %>%
       as_tibble(rownames = NA) %>%
       rownames_to_column("GEN")
     if (verbose == TRUE) {
-      pb$tick(tokens = list(what = names(vars[var])))
+      run_progress(pb,
+                   actual = var,
+                   text = paste("Evaluating trait", names(vars[var])))
     }
     listres[[paste(names(vars[var]))]] <- temp
   }
@@ -82,18 +84,18 @@ ecovalence <- function(.data, env, gen, rep, resp, verbose = TRUE) {
 
 #' Print an object of class ecovalence
 #'
-#' Print the \code{ecovalence} object in two ways. By default, the results
+#' Print the `ecovalence` object in two ways. By default, the results
 #' are shown in the R console. The results can also be exported to the directory
 #' into a *.txt file.
 #'
 #'
-#' @param x The \code{ecovalence} x
-#' @param export A logical argument. If \code{TRUE}, a *.txt file is exported to
+#' @param x The `ecovalence` x
+#' @param export A logical argument. If `TRUE`, a *.txt file is exported to
 #'   the working directory.
-#' @param file.name The name of the file if \code{export = TRUE}
+#' @param file.name The name of the file if `export = TRUE`
 #' @param digits The significant digits to be shown.
 #' @param ... Options used by the tibble package to format the output. See
-#'   \code{\link[tibble:formatting]{tibble::print()}} for more details.
+#'   [`tibble::print()`][tibble::formatting] for more details.
 #' @author Tiago Olivoto \email{tiagoolivoto@@gmail.com}
 #' @method print ecovalence
 #' @export
